==> haskell-hls-pragmas-plugin-1.0.0.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-pragmas-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-pragmas-plugin-1.0.0.0-4J2j7vpayuO4BzoZezZwMr
key:                  hls-pragmas-plugin-1.0.0.0-4J2j7vpayuO4BzoZezZwMr
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5c297f838b6d6917731794cb76b46383
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hls-pragmas-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hls-pragmas-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hls-pragmas-plugin-1.0.0.0

hs-libraries:         HShls-pragmas-plugin-1.0.0.0-4J2j7vpayuO4BzoZezZwMr
depends:
    base-4.15.0.0 extra-1.7.10-KOWRGAauShoAqEhi1tCnMz
    fuzzy-0.1.0.0-31FUqgDFH0kJvJL7uWbShB
    ghcide-1.4.0.3-DaG8Z99riC6EZzxw5ww9RS
    hls-plugin-api-1.1.0.2-AfmaNwfyKAd7cI5xZDgzC8
    lens-5.0.1-JARNcyPBw8gAo3FWHRCpjy
    lsp-1.2.0.0-3GjGXg7gNYsA4yR8er8w5M text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-pragmas-plugin-1.0.0.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-pragmas-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-pragmas-plugin-1.0.0.0-CDid0LFEpRl2jLWWMhAVPL
key:                  hls-pragmas-plugin-1.0.0.0-CDid0LFEpRl2jLWWMhAVPL
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  01357e5602c605196e60ef6f41a1bf98
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hls-pragmas-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hls-pragmas-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hls-pragmas-plugin-1.0.0.0

hs-libraries:         HShls-pragmas-plugin-1.0.0.0-CDid0LFEpRl2jLWWMhAVPL
depends:
    base-4.15.0.0 extra-1.7.10-3tDBYCQCoM76FUUqSWK3rB
    fuzzy-0.1.0.1-3umwirlK62cDpGVvrxIkCD
    ghcide-1.4.0.3-EBEJmb8CGCK7fAhaTonwPy
    hls-plugin-api-1.1.0.2-7DLcY7daEJQ1IplTXJ4dg4
    lens-5.0.1-KAh7DAnq23eK3Mb3yHYdKP
    lsp-1.2.0.0-5BxOf7csNHOJ3TnR1NvuDa text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-Wie4T3gD5k18ShmuaDNll

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
